@@ -5,47 +5,49 @@ module Nanoc::Int
   class OutdatednessStore < ::Nanoc::Int::Store
     include Nanoc::Int::ContractsSupport
 
-    contract C::KeywordArgs[site: C::Maybe[Nanoc::Int::Site], reps: Nanoc::Int::ItemRepRepo] => C::Any
-    def initialize(site: nil, reps:)
+    contract C::KeywordArgs[site: C::Maybe[Nanoc::Int::Site]] => C::Any
+    def initialize(site: nil)
       super(Nanoc::Int::Store.tmp_path_for(site: site, store_name: 'outdatedness'), 1)
 
-      @outdated_reps = Set.new
-      @all_reps = reps
+      @outdated_refs = Set.new
     end
 
     contract Nanoc::Int::ItemRep => C::Bool
     def include?(obj)
-      @outdated_reps.include?(obj)
+      @outdated_refs.include?(obj.reference)
     end
 
     contract Nanoc::Int::ItemRep => self
     def add(obj)
-      @outdated_reps << obj
+      @outdated_refs << obj.reference
       self
     end
 
     contract Nanoc::Int::ItemRep => self
     def remove(obj)
-      @outdated_reps.delete(obj)
+      @outdated_refs.delete(obj.reference)
       self
     end
 
-    contract C::None => C::ArrayOf[Nanoc::Int::ItemRep]
-    def to_a
-      @outdated_reps.to_a
+    contract C::None => C::Bool
+    def empty?
+      @outdated_refs.empty?
+    end
+
+    contract C::None => self
+    def clear
+      @outdated_refs = Set.new
+      self
     end
 
     protected
 
     def data
-      @outdated_reps.map(&:reference)
+      @outdated_refs
     end
 
     def data=(new_data)
-      outdated_refs = Set.new(new_data)
-      all_reps = Set.new(@all_reps)
-
-      @outdated_reps = Set.new(all_reps.select { |rep| outdated_refs.include?(rep.reference) })
+      @outdated_refs = Set.new(new_data)
     end
   end
 end
