@@ -14,12 +14,10 @@ module Nanoc::Int
       checksum_store =
         Nanoc::Int::ChecksumStore.new(site: site, objects: objects)
 
-      item_rep_repo = Nanoc::Int::ItemRepRepo.new
-
       action_provider ||= Nanoc::Int::ActionProvider.named(:rule_dsl).for(site)
 
       outdatedness_store =
-        Nanoc::Int::OutdatednessStore.new(site: site, reps: item_rep_repo)
+        Nanoc::Int::OutdatednessStore.new(site: site)
 
       compiled_content_cache =
         Nanoc::Int::CompiledContentCache.new(
@@ -32,7 +30,6 @@ module Nanoc::Int
         checksum_store: checksum_store,
         action_sequence_store: action_sequence_store,
         dependency_store: dependency_store,
-        reps: item_rep_repo,
         action_provider: action_provider,
         outdatedness_store: outdatedness_store,
       }
