@@ -1,9 +1,14 @@
 # frozen_string_literal: true
 
 module Nanoc
-  class PostCompileItemRepView < ::Nanoc::ItemRepView
+  class PostCompileItemRepView < ::Nanoc::BasicItemRepView
+    def item_view_class
+      Nanoc::PostCompileItemView
+    end
+
     def compiled_content(snapshot: nil)
-      snapshot_contents = @context.compilation_context.compiled_content_cache[unwrap]
+      compilation_context = @context.compilation_context
+      snapshot_contents = compilation_context.compiled_content_cache[unwrap]
 
       snapshot_name = snapshot || (snapshot_contents[:pre] ? :pre : :last)
 
