@@ -22,7 +22,11 @@ module Nanoc::Checking
       output_filenames = Dir[output_dir + '/**/*'].select { |f| File.file?(f) }
 
       # FIXME: ugly
-      view_context = site.compiler.compilation_context.create_view_context(Nanoc::Int::DependencyTracker::Null.new)
+      compiler = Nanoc::Int::Compiler.new_for(site)
+      res = compiler.run_until_reps_built
+      reps = res.fetch(:reps)
+      compilation_context = compiler.compilation_context(reps: reps)
+      view_context = compilation_context.create_view_context(Nanoc::Int::DependencyTracker::Null.new)
 
       context = {
         items: Nanoc::PostCompileItemCollectionView.new(site.items, view_context),
