@@ -21,6 +21,13 @@ require_relative 'cli/cleaning_stream'
 require_relative 'cli/stream_cleaners'
 require_relative 'cli/error_handler'
 
+require_relative 'cli/commands/compile_listeners/abstract'
+require_relative 'cli/commands/compile_listeners/debug_printer'
+require_relative 'cli/commands/compile_listeners/diff_generator'
+require_relative 'cli/commands/compile_listeners/file_action_printer'
+require_relative 'cli/commands/compile_listeners/timing_recorder'
+require_relative 'cli/commands/compile_listeners/aggregate'
+
 # @api private
 module Nanoc::CLI
   # @return [Boolean] true if debug output is enabled, false if not
@@ -96,7 +103,7 @@ module Nanoc::CLI
     @root_command = nil
 
     # Add root command
-    filename = File.dirname(__FILE__) + '/cli/commands/nanoc.rb'
+    filename = __dir__ + '/cli/commands/nanoc.rb'
     @root_command = load_command_at(filename)
 
     # Add help command
@@ -104,7 +111,7 @@ module Nanoc::CLI
     add_command(help_cmd)
 
     # Add other commands
-    cmd_filenames = Dir[File.dirname(__FILE__) + '/cli/commands/*.rb']
+    cmd_filenames = Dir[__dir__ + '/cli/commands/*.rb']
     cmd_filenames.each do |cmd_filename|
       next if File.basename(cmd_filename, '.rb') == 'nanoc'
       cmd = load_command_at(cmd_filename)
