@@ -14,7 +14,7 @@ module Nanoc::CLI::Commands
   class Check < ::Nanoc::CLI::CommandRunner
     def run
       validate_options_and_arguments
-      load_site(preprocess: true)
+      site = load_site
 
       runner = Nanoc::Checking::Runner.new(site)
 
