@@ -15,7 +15,8 @@ option :n, :'dry-run',      'show what would be deployed'
 module Nanoc::CLI::Commands
   class Deploy < ::Nanoc::CLI::CommandRunner
     def run
-      load_site(preprocess: true)
+      @site = load_site
+      Nanoc::Int::Compiler.new_for(@site).run_until_preprocessed
 
       if options[:'list-deployers']
         list_deployers
@@ -42,7 +43,7 @@ module Nanoc::CLI::Commands
         puts 'No deployment configurations.'
       else
         puts 'Available deployment configurations:'
-        deploy_configs.keys.each do |name|
+        deploy_configs.each_key do |name|
           puts "  #{name}"
         end
       end
@@ -80,14 +81,14 @@ module Nanoc::CLI::Commands
 
     def deployer_for(config)
       deployer_class_for_config(config).new(
-        site.config[:output_dir],
+        @site.config[:output_dir],
         config,
         dry_run: options[:'dry-run'],
       )
     end
 
     def check
-      runner = Nanoc::Checking::Runner.new(site)
+      runner = Nanoc::Checking::Runner.new(@site)
       if runner.dsl_present?
         puts 'Running issue checks…'
         is_success = runner.run_for_deploy
@@ -103,7 +104,7 @@ module Nanoc::CLI::Commands
     end
 
     def deploy_configs
-      site.config.fetch(:deploy, {})
+      @site.config.fetch(:deploy, {})
     end
 
     def deployer_class_for_config(config)
