@@ -13,13 +13,14 @@ module Nanoc::CLI::Commands
     def run
       require 'pry'
 
-      load_site(preprocess: options[:preprocess])
+      @site = load_site
+      Nanoc::Int::Compiler.new_for(@site).run_until_preprocessed if options[:preprocess]
 
       Nanoc::Int::Context.new(env).pry
     end
 
     def env
-      self.class.env_for_site(site)
+      self.class.env_for_site(@site)
     end
 
     def self.reps_for(site)
@@ -31,12 +32,9 @@ module Nanoc::CLI::Commands
     end
 
     def self.view_context_for(site)
-      Nanoc::ViewContext.new(
-        reps: reps_for(site),
+      Nanoc::ViewContextForShell.new(
         items: site.items,
-        dependency_tracker: Nanoc::Int::DependencyTracker::Null.new,
-        compilation_context: nil,
-        snapshot_repo: nil,
+        reps: reps_for(site),
       )
     end
 
