@@ -9,7 +9,7 @@ description <<~EOS
 EOS
 
 required :H, :handler, 'specify the handler to use (webrick/mongrel/...)'
-required :o, :host,    'specify the host to listen on (default: 0.0.0.0)'
+required :o, :host,    'specify the host to listen on (default: 127.0.0.1)'
 required :p, :port,    'specify the port to listen on (default: 3000)'
 
 module Nanoc::CLI::Commands
@@ -20,12 +20,12 @@ module Nanoc::CLI::Commands
       load_adsf
       require 'rack'
 
-      load_site
+      @site = load_site
 
       # Set options
       options_for_rack = {
         Port: (options[:port] || 3000).to_i,
-        Host: (options[:host] || '0.0.0.0'),
+        Host: (options[:host] || '127.0.0.1'),
       }
 
       # Get handler
@@ -40,7 +40,7 @@ module Nanoc::CLI::Commands
       end
 
       # Build app
-      site = self.site
+      site = @site
       app = Rack::Builder.new do
         use Rack::CommonLogger
         use Rack::ShowExceptions
@@ -52,6 +52,10 @@ module Nanoc::CLI::Commands
         run Rack::File.new(site.config[:output_dir])
       end.to_app
 
+      # Print a link
+      url = "http://#{options_for_rack[:Host]}:#{options_for_rack[:Port]}/"
+      puts "View the site at #{url}"
+
       # Run autocompiler
       handler.run(app, options_for_rack)
     end
