@@ -146,23 +146,6 @@ module Nanoc::CLI
 
     protected
 
-    # @return [Boolean] true if debug output is enabled, false if not
-    #
-    # @see Nanoc::CLI.debug?
-    def debug?
-      Nanoc::CLI.debug?
-    end
-
-    # @return [Nanoc::Int::Site] The site that is currently being processed
-    def site
-      @command && @command.site
-    end
-
-    # @return [Nanoc::Int::Compiler] The compiler for the current site
-    def compiler
-      site && site.compiler
-    end
-
     # @return [Hash<String, Array>] A hash containing the gem names as keys and gem versions as value
     def gems_and_versions
       gems = {}
