@@ -82,14 +82,14 @@ module Nanoc::Deploying::Deployers
 
     # @see Nanoc::Deploying::Deployer#run
     def run
-      require 'fog'
+      require 'fog/core'
 
       src      = File.expand_path(source_path)
       bucket   = config[:bucket] || config[:bucket_name]
       path     = config[:path]
       cdn_id   = config[:cdn_id]
 
-      if path && path.end_with?('/')
+      if path&.end_with?('/')
         raise "The path `#{path}` is not supposed to have a trailing slash"
       end
 
@@ -126,6 +126,9 @@ module Nanoc::Deploying::Deployers
 
     def connect
       ::Fog::Storage.new(config_for_fog)
+    rescue ArgumentError
+      require "fog/#{config[:provider]}"
+      ::Fog::Storage.new(config_for_fog)
     end
 
     def get_or_create_bucket(connection, bucket, path)
