@@ -16,7 +16,7 @@ module Nanoc::Filters
     def run(content, params = {})
       options = params.merge(
         nanoc_current_filter: self,
-        filename: @item && @item.raw_filename,
+        filename: @item&.raw_filename,
       )
       engine = ::Sass::Engine.new(content, options)
       engine.render
