@@ -17,7 +17,7 @@ module Nanoc::Helpers
         case target
         when String
           target
-        when Nanoc::ItemWithRepsView, Nanoc::ItemWithoutRepsView, Nanoc::ItemRepView
+        when Nanoc::CompilationItemView, Nanoc::BasicItemView, Nanoc::BasicItemRepView
           raise "Cannot create a link to #{target.inspect} because this target is not outputted (its routing rule returns nil)" if target.path.nil?
           target.path
         else
@@ -42,7 +42,7 @@ module Nanoc::Helpers
       # Find path
       path = target.is_a?(String) ? target : target.path
 
-      if @item_rep && @item_rep.path == path
+      if @item_rep&.path == path
         # Create message
         "<span class=\"active\">#{text}</span>"
       else
