@@ -53,14 +53,18 @@ module Nanoc::RuleDSL
         Nanoc::Int::InMemDataSource.new(ctx.items.unwrap, ctx.layouts.unwrap)
     end
 
-    def postprocess(site, reps)
+    def postprocess(site, compiler, reps)
       dependency_tracker = Nanoc::Int::DependencyTracker::Null.new
+
+      res = compiler.run_until_reps_built
+      reps = res.fetch(:reps)
+
       view_context =
-        Nanoc::ViewContext.new(
+        Nanoc::ViewContextForCompilation.new(
           reps: reps,
           items: site.items,
           dependency_tracker: dependency_tracker,
-          compilation_context: site.compiler.compilation_context,
+          compilation_context: compiler.compilation_context(reps: reps),
           snapshot_repo: nil,
         )
       ctx = new_postprocessor_context(site, view_context)
@@ -72,15 +76,8 @@ module Nanoc::RuleDSL
 
     # @api private
     def new_preprocessor_context(site)
-      dependency_tracker = Nanoc::Int::DependencyTracker::Null.new
       view_context =
-        Nanoc::ViewContext.new(
-          reps: nil,
-          items: nil,
-          dependency_tracker: dependency_tracker,
-          compilation_context: nil,
-          snapshot_repo: nil,
-        )
+        Nanoc::ViewContextForPreCompilation.new(items: site.items)
 
       Nanoc::Int::Context.new(
         config: Nanoc::MutableConfigView.new(site.config, view_context),
