@@ -10,14 +10,14 @@ module Nanoc::RuleDSL
     # @param [Nanoc::Int::ItemRep] rep
     # @param [Nanoc::Int::Site] site
     # @param [Nanoc::Int::Executor, Nanoc::RuleDSL::RecordingExecutor] executor
-    # @param [Nanoc::ViewContext] view_context
+    # @param [Nanoc::ViewContextForCompilation] view_context
     def initialize(rep:, site:, executor:, view_context:)
       @_executor = executor
 
       super({
-        item: Nanoc::ItemWithoutRepsView.new(rep.item, view_context),
-        rep: Nanoc::ItemRepView.new(rep, view_context),
-        item_rep: Nanoc::ItemRepView.new(rep, view_context),
+        item: Nanoc::BasicItemView.new(rep.item, view_context),
+        rep: Nanoc::BasicItemRepView.new(rep, view_context),
+        item_rep: Nanoc::BasicItemRepView.new(rep, view_context),
         items: Nanoc::ItemCollectionWithoutRepsView.new(site.items, view_context),
         layouts: Nanoc::LayoutCollectionView.new(site.layouts, view_context),
         config: Nanoc::ConfigView.new(site.config, view_context),
