@@ -252,11 +252,11 @@ describe Nanoc::Int::Checksummer do
     end
   end
 
-  context 'Nanoc::ItemWithRepsView' do
-    let(:obj) { Nanoc::ItemWithRepsView.new(item, nil) }
+  context 'Nanoc::CompilationItemView' do
+    let(:obj) { Nanoc::CompilationItemView.new(item, nil) }
     let(:item) { Nanoc::Int::Item.new('asdf', {}, '/foo.md') }
 
-    it { is_expected.to eql('Nanoc::ItemWithRepsView<Nanoc::Int::Item<content=Nanoc::Int::TextualContent<String<asdf>>,attributes=Hash<>,identifier=Nanoc::Identifier<String</foo.md>>>>') }
+    it { is_expected.to eql('Nanoc::CompilationItemView<Nanoc::Int::Item<content=Nanoc::Int::TextualContent<String<asdf>>,attributes=Hash<>,identifier=Nanoc::Identifier<String</foo.md>>>>') }
   end
 
   context 'Nanoc::Int::ItemRep' do
@@ -266,19 +266,27 @@ describe Nanoc::Int::Checksummer do
     it { is_expected.to eql('Nanoc::Int::ItemRep<item=Nanoc::Int::Item<content=Nanoc::Int::TextualContent<String<asdf>>,attributes=Hash<>,identifier=Nanoc::Identifier<String</foo.md>>>,name=Symbol<pdf>>') }
   end
 
-  context 'Nanoc::ItemRepView' do
-    let(:obj) { Nanoc::ItemRepView.new(rep, :_unused_context) }
+  context 'Nanoc::BasicItemRepView' do
+    let(:obj) { Nanoc::BasicItemRepView.new(rep, :_unused_context) }
     let(:rep) { Nanoc::Int::ItemRep.new(item, :pdf) }
     let(:item) { Nanoc::Int::Item.new('asdf', {}, '/foo.md') }
 
-    it { is_expected.to eql('Nanoc::ItemRepView<Nanoc::Int::ItemRep<item=Nanoc::Int::Item<content=Nanoc::Int::TextualContent<String<asdf>>,attributes=Hash<>,identifier=Nanoc::Identifier<String</foo.md>>>,name=Symbol<pdf>>>') }
+    it { is_expected.to eql('Nanoc::BasicItemRepView<Nanoc::Int::ItemRep<item=Nanoc::Int::Item<content=Nanoc::Int::TextualContent<String<asdf>>,attributes=Hash<>,identifier=Nanoc::Identifier<String</foo.md>>>,name=Symbol<pdf>>>') }
   end
 
-  context 'Nanoc::ItemWithoutRepsView' do
-    let(:obj) { Nanoc::ItemWithoutRepsView.new(item, nil) }
+  context 'Nanoc::CompilationItemRepView' do
+    let(:obj) { Nanoc::CompilationItemRepView.new(rep, :_unused_context) }
+    let(:rep) { Nanoc::Int::ItemRep.new(item, :pdf) }
     let(:item) { Nanoc::Int::Item.new('asdf', {}, '/foo.md') }
 
-    it { is_expected.to eql('Nanoc::ItemWithoutRepsView<Nanoc::Int::Item<content=Nanoc::Int::TextualContent<String<asdf>>,attributes=Hash<>,identifier=Nanoc::Identifier<String</foo.md>>>>') }
+    it { is_expected.to eql('Nanoc::CompilationItemRepView<Nanoc::Int::ItemRep<item=Nanoc::Int::Item<content=Nanoc::Int::TextualContent<String<asdf>>,attributes=Hash<>,identifier=Nanoc::Identifier<String</foo.md>>>,name=Symbol<pdf>>>') }
+  end
+
+  context 'Nanoc::BasicItemView' do
+    let(:obj) { Nanoc::BasicItemView.new(item, nil) }
+    let(:item) { Nanoc::Int::Item.new('asdf', {}, '/foo.md') }
+
+    it { is_expected.to eql('Nanoc::BasicItemView<Nanoc::Int::Item<content=Nanoc::Int::TextualContent<String<asdf>>,attributes=Hash<>,identifier=Nanoc::Identifier<String</foo.md>>>>') }
   end
 
   context 'Nanoc::LayoutView' do
@@ -362,9 +370,9 @@ describe Nanoc::Int::Checksummer do
       [
         'Nanoc::RuleDSL::RuleContext<',
         'item=',
-        'Nanoc::ItemWithoutRepsView<' + expected_item_checksum + '>',
+        'Nanoc::BasicItemView<' + expected_item_checksum + '>',
         ',rep=',
-        'Nanoc::ItemRepView<' + expected_item_rep_checksum + '>',
+        'Nanoc::BasicItemRepView<' + expected_item_rep_checksum + '>',
         ',items=',
         'Nanoc::ItemCollectionWithoutRepsView<Array<' + expected_item_checksum + ',>>',
         ',layouts=',
