@@ -82,20 +82,21 @@ describe Nanoc::Filter do
     let(:item_views) { [item_view] }
 
     let(:item) { Nanoc::Int::Item.new('foo', {}, '/stuff.md') }
-    let(:item_view) { Nanoc::ItemWithRepsView.new(item, view_context) }
+    let(:item_view) { Nanoc::CompilationItemView.new(item, view_context) }
     let(:rep) { Nanoc::Int::ItemRep.new(item, :default) }
 
     let(:view_context) do
-      Nanoc::ViewContext.new(
-        reps: reps,
-        items: double(:items),
-        dependency_tracker: dependency_tracker,
+      Nanoc::ViewContextForCompilation.new(
+        reps:                reps,
+        items:               Nanoc::Int::ItemCollection.new(config),
+        dependency_tracker:  dependency_tracker,
         compilation_context: double(:compilation_context),
-        snapshot_repo: double(:snapshot_repo),
+        snapshot_repo:       double(:snapshot_repo),
       )
     end
 
     let(:dependency_tracker) { double(:dependency_tracker) }
+    let(:config) { Nanoc::Int::Configuration.new }
 
     let(:reps) { Nanoc::Int::ItemRepRepo.new }
 
