@@ -1,10 +1,9 @@
 # frozen_string_literal: true
 
 describe Nanoc::Int::OutdatednessStore do
-  subject(:store) { described_class.new(site: site, reps: reps) }
+  subject(:store) { described_class.new(site: site) }
 
   let(:site) { double(:site) }
-  let(:reps) { Nanoc::Int::ItemRepRepo.new }
 
   let(:item) { Nanoc::Int::Item.new('foo', {}, '/foo.md') }
   let(:rep) { Nanoc::Int::ItemRep.new(item, :foo) }
@@ -54,19 +53,6 @@ describe Nanoc::Int::OutdatednessStore do
     end
   end
 
-  describe '#to_a' do
-    subject { store.to_a }
-
-    context 'nothing added' do
-      it { is_expected.to be_empty }
-    end
-
-    context 'one rep added' do
-      before { store.add(rep) }
-      it { is_expected.to eql([rep]) }
-    end
-  end
-
   describe 'reloading' do
     subject do
       store.store
@@ -75,27 +61,12 @@ describe Nanoc::Int::OutdatednessStore do
     end
 
     context 'not added' do
-      context 'rep part of new reps' do
-        before { reps << rep }
-        it { is_expected.not_to be }
-      end
-
-      context 'rep not part of new reps' do
-        it { is_expected.not_to be }
-      end
+      it { is_expected.not_to be }
     end
 
     context 'added' do
       before { store.add(rep) }
-
-      context 'rep part of new reps' do
-        before { reps << rep }
-        it { is_expected.to be }
-      end
-
-      context 'rep not part of new reps' do
-        it { is_expected.not_to be }
-      end
+      it { is_expected.to be }
     end
   end
 end
