@@ -400,12 +400,12 @@ describe Nanoc::Int::Executor do
     end
 
     let(:view_context) do
-      Nanoc::ViewContext.new(
-        reps: double(:reps),
-        items: double(:items),
-        dependency_tracker: dependency_tracker,
+      Nanoc::ViewContextForCompilation.new(
+        reps:                Nanoc::Int::ItemRepRepo.new,
+        items:               Nanoc::Int::ItemCollection.new(config),
+        dependency_tracker:  dependency_tracker,
         compilation_context: double(:compilation_context),
-        snapshot_repo: snapshot_repo,
+        snapshot_repo:       snapshot_repo,
       )
     end
 
@@ -482,7 +482,7 @@ describe Nanoc::Int::Executor do
         let(:layout_content) { 'head <%= @item_rep.compiled_content(snapshot: :pre) %> foot' }
 
         let(:assigns) do
-          { item_rep: Nanoc::ItemRepView.new(rep, view_context) }
+          { item_rep: Nanoc::CompilationItemRepView.new(rep, view_context) }
         end
 
         before do
@@ -653,7 +653,7 @@ describe Nanoc::Int::Executor do
       let(:arg) { '/default' }
 
       let(:layouts) do
-        [Nanoc::Int::Layout.new('head <%= @foo %> foot', {}, '/default/')]
+        [Nanoc::Int::Layout.new('head <%= @foo %> foot', {}, Nanoc::Identifier.new('/default/', type: :legacy))]
       end
 
       it { is_expected.to eq(layouts[0]) }
