@@ -1,12 +1,14 @@
 # frozen_string_literal: true
 
-describe Nanoc::ItemWithRepsView do
+require_relative 'support/document_view_examples'
+
+describe Nanoc::CompilationItemView do
   let(:entity_class) { Nanoc::Int::Item }
   let(:other_view_class) { Nanoc::LayoutView }
   it_behaves_like 'a document view'
 
   let(:view_context) do
-    Nanoc::ViewContext.new(
+    Nanoc::ViewContextForCompilation.new(
       reps: reps,
       items: items,
       dependency_tracker: dependency_tracker,
@@ -15,8 +17,8 @@ describe Nanoc::ItemWithRepsView do
     )
   end
 
-  let(:reps) { [] }
-  let(:items) { [] }
+  let(:reps) { Nanoc::Int::ItemRepRepo.new }
+  let(:items) { Nanoc::Int::ItemCollection.new(config) }
   let(:dependency_tracker) { Nanoc::Int::DependencyTracker.new(dependency_store) }
   let(:dependency_store) { Nanoc::Int::DependencyStore.new(empty_items, empty_layouts, config) }
   let(:compilation_context) { double(:compilation_context) }
@@ -53,15 +55,15 @@ describe Nanoc::ItemWithRepsView do
     subject { view.parent }
 
     context 'with parent' do
-      let(:parent_item) do
-        Nanoc::Int::Item.new('parent', {}, '/parent/')
-      end
-
       context 'full identifier' do
         let(:identifier) do
           Nanoc::Identifier.new('/parent/me.md')
         end
 
+        let(:parent_item) do
+          Nanoc::Int::Item.new('parent', {}, '/parent.md')
+        end
+
         it 'raises' do
           expect { subject }.to raise_error(Nanoc::Int::Errors::CannotGetParentOrChildrenOfNonLegacyItem)
         end
@@ -72,8 +74,12 @@ describe Nanoc::ItemWithRepsView do
           Nanoc::Identifier.new('/parent/me/', type: :legacy)
         end
 
+        let(:parent_item) do
+          Nanoc::Int::Item.new('parent', {}, Nanoc::Identifier.new('/parent/', type: :legacy))
+        end
+
         it 'returns a view for the parent' do
-          expect(subject.class).to eql(Nanoc::ItemWithRepsView)
+          expect(subject.class).to eql(Nanoc::CompilationItemView)
           expect(subject.unwrap).to eql(parent_item)
         end
 
@@ -91,11 +97,12 @@ describe Nanoc::ItemWithRepsView do
         end
 
         context 'with root parent' do
-          let(:parent_item) { Nanoc::Int::Item.new('parent', {}, '/') }
+          let(:parent_item) { Nanoc::Int::Item.new('parent', {}, parent_identifier) }
           let(:identifier) { Nanoc::Identifier.new('/me/', type: :legacy) }
+          let(:parent_identifier) { Nanoc::Identifier.new('/', type: :legacy) }
 
           it 'returns a view for the parent' do
-            expect(subject.class).to eql(Nanoc::ItemWithRepsView)
+            expect(subject.class).to eql(Nanoc::CompilationItemView)
             expect(subject.unwrap).to eql(parent_item)
           end
         end
@@ -133,10 +140,6 @@ describe Nanoc::ItemWithRepsView do
       Nanoc::Int::Item.new('me', {}, identifier)
     end
 
-    let(:children) do
-      [Nanoc::Int::Item.new('child', {}, '/me/child/')]
-    end
-
     let(:view) { described_class.new(item, view_context) }
 
     let(:items) do
@@ -156,6 +159,10 @@ describe Nanoc::ItemWithRepsView do
         Nanoc::Identifier.new('/me.md')
       end
 
+      let(:children) do
+        [Nanoc::Int::Item.new('child', {}, '/me/child.md')]
+      end
+
       it 'raises' do
         expect { subject }.to raise_error(Nanoc::Int::Errors::CannotGetParentOrChildrenOfNonLegacyItem)
       end
@@ -166,9 +173,13 @@ describe Nanoc::ItemWithRepsView do
         Nanoc::Identifier.new('/me/', type: :legacy)
       end
 
+      let(:children) do
+        [Nanoc::Int::Item.new('child', {}, Nanoc::Identifier.new('/me/child/', type: :legacy))]
+      end
+
       it 'returns views for the children' do
         expect(subject.size).to eql(1)
-        expect(subject[0].class).to eql(Nanoc::ItemWithRepsView)
+        expect(subject[0].class).to eql(Nanoc::CompilationItemView)
         expect(subject[0].unwrap).to eql(children[0])
       end
 
@@ -194,7 +205,7 @@ describe Nanoc::ItemWithRepsView do
 
     it 'returns a proper item rep collection' do
       expect(subject.size).to eq(2)
-      expect(subject.class).to eql(Nanoc::ItemRepCollectionView)
+      expect(subject.class).to eql(Nanoc::CompilationItemRepCollectionView)
     end
 
     it 'returns a view with the right context' do
@@ -208,7 +219,7 @@ describe Nanoc::ItemWithRepsView do
     let(:view) { described_class.new(item, view_context) }
 
     let(:item) do
-      Nanoc::Int::Item.new('content', {}, '/asdf/')
+      Nanoc::Int::Item.new('content', {}, '/asdf')
     end
 
     let(:reps) do
@@ -276,7 +287,7 @@ describe Nanoc::ItemWithRepsView do
       let(:params) { { rep: :other } }
 
       it 'raises an error' do
-        expect { subject }.to raise_error(Nanoc::ItemRepCollectionView::NoSuchItemRepError)
+        expect { subject }.to raise_error(Nanoc::BasicItemRepCollectionView::NoSuchItemRepError)
       end
     end
   end
@@ -341,7 +352,7 @@ describe Nanoc::ItemWithRepsView do
       let(:params) { { rep: :other } }
 
       it 'raises an error' do
-        expect { subject }.to raise_error(Nanoc::ItemRepCollectionView::NoSuchItemRepError)
+        expect { subject }.to raise_error(Nanoc::BasicItemRepCollectionView::NoSuchItemRepError)
       end
     end
   end
@@ -355,11 +366,11 @@ describe Nanoc::ItemWithRepsView do
   end
 
   describe '#inspect' do
-    let(:item) { Nanoc::Int::Item.new('content', {}, '/asdf/') }
+    let(:item) { Nanoc::Int::Item.new('content', {}, '/asdf') }
     let(:view) { described_class.new(item, nil) }
 
     subject { view.inspect }
 
-    it { is_expected.to eql('<Nanoc::ItemWithRepsView identifier=/asdf/>') }
+    it { is_expected.to eql('<Nanoc::CompilationItemView identifier=/asdf>') }
   end
 end
