@@ -1,14 +1,20 @@
 # frozen_string_literal: true
 
+require_relative 'support/item_rep_view_examples'
+
 describe Nanoc::PostCompileItemRepView do
+  let(:expected_item_view_class) { Nanoc::PostCompileItemView }
+
+  it_behaves_like 'an item rep view'
+
   let(:item_rep) { Nanoc::Int::ItemRep.new(item, :jacques) }
-  let(:item) { Nanoc::Int::Item.new('asdf', {}, '/foo/') }
+  let(:item) { Nanoc::Int::Item.new('asdf', {}, '/foo') }
   let(:view) { described_class.new(item_rep, view_context) }
 
   let(:view_context) do
-    Nanoc::ViewContext.new(
-      reps: reps,
-      items: items,
+    Nanoc::ViewContextForCompilation.new(
+      reps:                Nanoc::Int::ItemRepRepo.new,
+      items:               Nanoc::Int::ItemCollection.new(config),
       dependency_tracker: dependency_tracker,
       compilation_context: compilation_context,
       snapshot_repo: snapshot_repo,
