@@ -1,13 +1,11 @@
 # frozen_string_literal: true
 
-describe Nanoc::CLI::Commands::ShowRules, stdio: true do
+describe Nanoc::CLI::Commands::ShowRules, stdio: true, site: true do
   describe '#run' do
     subject { runner.run }
 
     let(:runner) do
-      described_class.new(options, arguments, command).tap do |runner|
-        runner.site = site
-      end
+      described_class.new(options, arguments, command)
     end
 
     let(:options) { {} }
@@ -60,7 +58,7 @@ describe Nanoc::CLI::Commands::ShowRules, stdio: true do
     let(:config) { Nanoc::Int::Configuration.new }
 
     let(:action_provider) { double(:action_provider, rules_collection: rules_collection) }
-    let(:compiler) { double(:compiler, action_provider: action_provider, reps: reps) }
+    let(:compiler) { double(:compiler) }
 
     let(:rules_collection) do
       Nanoc::RuleDSL::RulesCollection.new.tap do |rc|
@@ -105,15 +103,15 @@ describe Nanoc::CLI::Commands::ShowRules, stdio: true do
         .gsub(/^ {8}/, '')
     end
 
-    before do
-      expect(compiler).to receive(:build_reps).once
-    end
-
     it 'writes item and layout rules to stdout' do
+      expect(runner).to receive(:load_site).and_return(site)
+      expect(Nanoc::Int::Compiler).to receive(:new_for).with(site).and_return(compiler)
+      expect(compiler).to receive(:run_until_reps_built).and_return(reps: reps)
+      expect(Nanoc::RuleDSL::ActionProvider).to receive(:for).with(site).and_return(action_provider)
       expect { subject }.to output(expected_out).to_stdout
     end
 
-    it 'writes status informaion to stderr' do
+    it 'writes status information to stderr' do
       expect { subject }.to output("Loading site… done\n").to_stderr
     end
   end
