@@ -16,14 +16,24 @@ describe(Nanoc::RuleDSL::RuleContext) do
   let(:executor) { double(:executor) }
   let(:reps) { double(:reps) }
   let(:compilation_context) { double(:compilation_context) }
-  let(:view_context) { Nanoc::ViewContext.new(reps: reps, items: items, dependency_tracker: dependency_tracker, compilation_context: compilation_context, snapshot_repo: snapshot_repo) }
+
+  let(:view_context) do
+    Nanoc::ViewContextForCompilation.new(
+      reps:                Nanoc::Int::ItemRepRepo.new,
+      items:               items,
+      dependency_tracker:  dependency_tracker,
+      compilation_context: compilation_context,
+      snapshot_repo:       snapshot_repo,
+    )
+  end
+
   let(:dependency_tracker) { double(:dependency_tracker) }
   let(:snapshot_repo) { double(:snapshot_repo) }
 
   describe '#initialize' do
     it 'wraps objects in view classes' do
-      expect(subject.rep.class).to eql(Nanoc::ItemRepView)
-      expect(subject.item.class).to eql(Nanoc::ItemWithoutRepsView)
+      expect(subject.rep.class).to eql(Nanoc::BasicItemRepView)
+      expect(subject.item.class).to eql(Nanoc::BasicItemView)
       expect(subject.config.class).to eql(Nanoc::ConfigView)
       expect(subject.layouts.class).to eql(Nanoc::LayoutCollectionView)
       expect(subject.items.class).to eql(Nanoc::ItemCollectionWithoutRepsView)
@@ -42,7 +52,7 @@ describe(Nanoc::RuleDSL::RuleContext) do
     subject { rule_context.item }
 
     it 'is a view without reps access' do
-      expect(subject.class).to eql(Nanoc::ItemWithoutRepsView)
+      expect(subject.class).to eql(Nanoc::BasicItemView)
     end
 
     it 'contains the right item' do
@@ -67,7 +77,7 @@ describe(Nanoc::RuleDSL::RuleContext) do
       end
 
       it 'wraps the parent in a view without reps access' do
-        expect(subject.parent.class).to eql(Nanoc::ItemWithoutRepsView)
+        expect(subject.parent.class).to eql(Nanoc::BasicItemView)
         expect(subject.parent).not_to respond_to(:compiled_content)
         expect(subject.parent).not_to respond_to(:path)
         expect(subject.parent).not_to respond_to(:reps)
@@ -78,7 +88,7 @@ describe(Nanoc::RuleDSL::RuleContext) do
       end
 
       it 'wraps the children in a view without reps access' do
-        expect(subject.children.map(&:class)).to eql([Nanoc::ItemWithoutRepsView])
+        expect(subject.children.map(&:class)).to eql([Nanoc::BasicItemView])
         expect(subject.children[0]).not_to respond_to(:compiled_content)
         expect(subject.children[0]).not_to respond_to(:path)
         expect(subject.children[0]).not_to respond_to(:reps)
