@@ -18,9 +18,9 @@ class Nanoc::Filters::KramdownTest < Nanoc::TestCase
     if_have 'kramdown' do
       # Create item
       item = Nanoc::Int::Item.new('foo', {}, '/foo.md')
-      item_view = Nanoc::ItemWithRepsView.new(item, nil)
+      item_view = Nanoc::CompilationItemView.new(item, nil)
       item_rep = Nanoc::Int::ItemRep.new(item, :default)
-      item_rep_view = Nanoc::ItemRepView.new(item_rep, nil)
+      item_rep_view = Nanoc::CompilationItemRepView.new(item_rep, nil)
 
       # Create filter
       filter = ::Nanoc::Filters::Kramdown.new(item: item_view, item_rep: item_rep_view)
@@ -38,9 +38,9 @@ class Nanoc::Filters::KramdownTest < Nanoc::TestCase
     if_have 'kramdown' do
       # Create item
       item = Nanoc::Int::Item.new('foo', {}, '/foo.md')
-      item_view = Nanoc::ItemWithRepsView.new(item, nil)
+      item_view = Nanoc::CompilationItemView.new(item, nil)
       item_rep = Nanoc::Int::ItemRep.new(item, :default)
-      item_rep_view = Nanoc::ItemRepView.new(item_rep, nil)
+      item_rep_view = Nanoc::CompilationItemRepView.new(item_rep, nil)
 
       # Create filter
       filter = ::Nanoc::Filters::Kramdown.new(item: item_view, item_rep: item_rep_view)
