@@ -101,21 +101,23 @@ EOS
   end
 
   def new_view_context
-    Nanoc::ViewContext.new(
-      reps: :__irrelevat_reps,
-      items: :__irrelevat_items,
-      dependency_tracker: @dependency_tracker,
+    config = Nanoc::Int::Configuration.new
+
+    Nanoc::ViewContextForCompilation.new(
+      reps:                Nanoc::Int::ItemRepRepo.new,
+      items:               Nanoc::Int::ItemCollection.new(config),
+      dependency_tracker:  @dependency_tracker,
       compilation_context: :__irrelevat_compiler,
-      snapshot_repo: :__irrelevant_snapshot_repo,
+      snapshot_repo:       :__irrelevant_snapshot_repo,
     )
   end
 
   def test_filter_as_layout
     if_have 'nokogiri' do
       # Create our data objects
-      item = Nanoc::Int::Item.new(SAMPLE_XML_IN, {}, '/content/')
-      item = Nanoc::ItemWithRepsView.new(item, new_view_context)
-      layout = Nanoc::Int::Layout.new(SAMPLE_XSL, {}, '/layout/')
+      item = Nanoc::Int::Item.new(SAMPLE_XML_IN, {}, '/content')
+      item = Nanoc::CompilationItemView.new(item, new_view_context)
+      layout = Nanoc::Int::Layout.new(SAMPLE_XSL, {}, '/layout')
       layout = Nanoc::LayoutView.new(layout, new_view_context)
 
       # Create an instance of the filter
@@ -139,9 +141,9 @@ EOS
   def test_filter_with_params
     if_have 'nokogiri' do
       # Create our data objects
-      item = Nanoc::Int::Item.new(SAMPLE_XML_IN_WITH_PARAMS, {}, '/content/')
-      item = Nanoc::ItemWithRepsView.new(item, new_view_context)
-      layout = Nanoc::Int::Layout.new(SAMPLE_XSL_WITH_PARAMS, {}, '/layout/')
+      item = Nanoc::Int::Item.new(SAMPLE_XML_IN_WITH_PARAMS, {}, '/content')
+      item = Nanoc::CompilationItemView.new(item, new_view_context)
+      layout = Nanoc::Int::Layout.new(SAMPLE_XSL_WITH_PARAMS, {}, '/layout')
       layout = Nanoc::LayoutView.new(layout, new_view_context)
 
       # Create an instance of the filter
@@ -165,9 +167,9 @@ EOS
   def test_filter_with_omit_xml_decl
     if_have 'nokogiri' do
       # Create our data objects
-      item = Nanoc::Int::Item.new(SAMPLE_XML_IN_WITH_OMIT_XML_DECL, {}, '/content/')
-      item = Nanoc::ItemWithRepsView.new(item, new_view_context)
-      layout = Nanoc::Int::Layout.new(SAMPLE_XSL_WITH_OMIT_XML_DECL, {}, '/layout/')
+      item = Nanoc::Int::Item.new(SAMPLE_XML_IN_WITH_OMIT_XML_DECL, {}, '/content')
+      item = Nanoc::CompilationItemView.new(item, new_view_context)
+      layout = Nanoc::Int::Layout.new(SAMPLE_XSL_WITH_OMIT_XML_DECL, {}, '/layout')
       layout = Nanoc::LayoutView.new(layout, new_view_context)
 
       # Create an instance of the filter
