@@ -12,12 +12,14 @@ class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
   end
 
   def view_context_for(item)
-    Nanoc::ViewContext.new(
-      reps: item_rep_repo_for(item),
-      items: :__irrelevant__,
-      dependency_tracker: :__irrelevant__,
+    config = Nanoc::Int::Configuration.new
+
+    Nanoc::ViewContextForCompilation.new(
+      reps:                item_rep_repo_for(item),
+      items:               Nanoc::Int::ItemCollection.new(config),
+      dependency_tracker:  :__irrelevant__,
       compilation_context: :__irrelevant__,
-      snapshot_repo: snapshot_repo,
+      snapshot_repo:       snapshot_repo,
     )
   end
 
@@ -80,9 +82,9 @@ class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
       foot
 EOS
 
-    item = Nanoc::Int::Item.new('content', {}, '/')
+    item = Nanoc::Int::Item.new('content', {}, '/asdf')
     view_context = view_context_for(item)
-    @item = Nanoc::ItemWithRepsView.new(item, view_context_for(item))
+    @item = Nanoc::CompilationItemView.new(item, view_context_for(item))
     @config = Nanoc::ConfigView.new(Nanoc::Int::Configuration.new, view_context)
 
     result = ::ERB.new(content).result(binding)
